datastructuretools.TreeContainer
================================

.. abjad-lineage:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer

.. autoclass:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.children
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.depth
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.graph_order
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.leaves
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.nodes
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.parent
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.root
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.append
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.extend
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.index
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.insert
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.pop
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__contains__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__delitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__ge__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__getitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__getstate__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__gt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__iter__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__le__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__len__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__lt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__repr__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__setitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer.__setstate__
   :noindex:
